@@ -1,6 +1,6 @@
 /*
  * libInstPatch
- * Copyright (C) 1999-2010 Joshua "Element" Green <jgreen@users.sourceforge.net>
+ * Copyright (C) 1999-2014 Element Green <element@elementsofsound.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -17,12 +17,6 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA or on the web at http://www.gnu.org.
  */
-/**
- * SECTION: util
- * @short_description: Utility functions
- * @see_also: 
- * @stability: Stable
- */
 #ifndef __IPATCH_UTIL_H__
 #define __IPATCH_UTIL_H__
 
@@ -37,8 +31,10 @@ extern GValue *ipatch_util_value_bool_false;
 #define IPATCH_UTIL_VALUE_BOOL(b) \
   ((b) ? ipatch_util_value_bool_true : ipatch_util_value_bool_false)
 
-guint ipatch_util_value_hash (GValue *val);
-guint ipatch_util_value_array_hash (GValueArray *valarray);
-guint64 ipatch_util_file_size (const char *fname, GError **err);
+guint ipatch_util_value_hash(GValue *val);
+guint ipatch_util_value_array_hash(GValueArray *valarray);
+guint64 ipatch_util_file_size(const char *fname, GError **err);
+char *ipatch_util_abs_filename(const char *filename);
+void ipatch_util_weakref_destroy(gpointer value);
 
 #endif
